<?php
/**
 * Install sample style kits.
 *
 * @package AnalogWP
 * @since   1.2
 */

namespace Analog;

/**
 * Class Install_Stylekits.
 *
 * @package Analog
 */
class Install_Stylekits extends Base {
	/**
	 * Perform Style kits install.
	 *
	 * @return bool False is succeeded, true if has errors.
	 */
	public function perform_install() {
		$posts      = self::post_data();
		$has_errors = false;

		foreach ( $posts as $post ) {
			$post = wp_insert_post(
				[
					'post_type'   => 'ang_tokens',
					'post_status' => 'publish',
					'post_title'  => $post['title'],
					'post_name'   => $post['slug'],
					'meta_input'  => [
						'belongs_to'   => '',
						'_tokens_data' => $post['meta'],
					],
				]
			);

			if ( is_wp_error( $post ) ) {
				$has_errors = true;
			}
		}

		return $has_errors;
	}

	/**
	 * Post data for default style kits.
	 *
	 * @return array
	 */
	private function post_data() {
		$posts = [
			[
				'slug'  => 'ang-struct',
				'title' => 'Struct',
				'meta'  => '{"ang_body_typography":"custom","ang_body_font_family":"Barlow","ang_body_font_size":{"unit":"rem","size":1.2,"sizes":[]},"ang_body_font_weight":"normal","ang_body_line_height":{"unit":"em","size":1.6,"sizes":[]},"ang_paragraph_typography":"custom","ang_paragraph_font_size":{"unit":"em","size":1.2,"sizes":[]},"ang_paragraph_font_size_tablet":{"unit":"em","size":1.2,"sizes":[]},"ang_paragraph_font_size_mobile":{"unit":"em","size":1,"sizes":[]},"ang_paragraph_line_height":{"unit":"em","size":1.6,"sizes":[]},"ang_paragraph_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_paragraph_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_paragraph_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_paragraph_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_paragraph_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_1_typography":"custom","ang_heading_1_font_size":{"unit":"em","size":3.2,"sizes":[]},"ang_heading_1_font_size_tablet":{"unit":"em","size":2.5,"sizes":[]},"ang_heading_1_font_size_mobile":{"unit":"em","size":2,"sizes":[]},"ang_heading_1_font_weight":"900","ang_heading_1_line_height":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_2_typography":"custom","ang_heading_2_font_size":{"unit":"em","size":2.5,"sizes":[]},"ang_heading_2_font_size_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_2_font_size_mobile":{"unit":"em","size":1.6,"sizes":[]},"ang_heading_2_font_weight":"900","ang_heading_2_line_height":{"unit":"em","size":1,"sizes":[]},"ang_heading_3_typography":"custom","ang_heading_3_font_size":{"unit":"em","size":2.3,"sizes":[]},"ang_heading_3_font_size_tablet":{"unit":"em","size":1.6,"sizes":[]},"ang_heading_3_font_size_mobile":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_3_font_weight":"900","ang_heading_3_line_height":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_4_typography":"custom","ang_heading_4_font_size":{"unit":"em","size":1.6,"sizes":[]},"ang_heading_4_font_size_tablet":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_4_font_size_mobile":{"unit":"em","size":1,"sizes":[]},"ang_heading_4_font_weight":"900","ang_heading_4_line_height":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_5_typography":"custom","ang_heading_5_font_size":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_5_font_size_tablet":{"unit":"em","size":1,"sizes":[]},"ang_heading_5_font_size_mobile":{"unit":"em","size":0.9,"sizes":[]},"ang_heading_5_font_weight":"900","ang_heading_5_line_height":{"unit":"em","size":1,"sizes":[]},"ang_heading_6_typography":"custom","ang_heading_6_font_size":{"unit":"em","size":0.9,"sizes":[]},"ang_heading_6_font_size_tablet":{"unit":"em","size":0.9,"sizes":[]},"ang_heading_6_font_size_mobile":{"unit":"em","size":0.8,"sizes":[]},"ang_heading_6_font_weight":"900","ang_heading_6_text_transform":"uppercase","ang_heading_6_letter_spacing":{"unit":"px","size":1,"sizes":[]},"ang_size_small":{"unit":"em","size":1.2,"sizes":[]},"ang_size_small_tablet":{"unit":"em","size":"","sizes":[]},"ang_size_small_mobile":{"unit":"em","size":0.9,"sizes":[]},"ang_size_medium":{"unit":"em","size":1.6,"sizes":[]},"ang_size_medium_tablet":{"unit":"em","size":"","sizes":[]},"ang_size_medium_mobile":{"unit":"em","size":1,"sizes":[]},"ang_size_large":{"unit":"em","size":2,"sizes":[]},"ang_size_large_tablet":{"unit":"em","size":"","sizes":[]},"ang_size_large_mobile":{"unit":"em","size":1.2,"sizes":[]},"ang_size_xl":{"unit":"em","size":2.5,"sizes":[]},"ang_size_xl_tablet":{"unit":"em","size":2,"sizes":[]},"ang_size_xl_mobile":{"unit":"em","size":1.6,"sizes":[]},"ang_size_xxl":{"unit":"em","size":4.2,"sizes":[]},"ang_size_xxl_tablet":{"unit":"em","size":3.6,"sizes":[]},"ang_size_xxl_mobile":{"unit":"em","size":2.5,"sizes":[]},"ang_column_gap_default":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_default_mobile":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_narrow":{"unit":"em","top":"0.625","right":"0.625","bottom":"0.625","left":"0.625","isLinked":true},"ang_column_gap_narrow_mobile":{"unit":"em","top":"0.625","right":"0.625","bottom":"0.625","left":"0.625","isLinked":true},"ang_column_gap_extended":{"unit":"em","top":"2.5","right":"2.5","bottom":"2.5","left":"2.5","isLinked":true},"ang_column_gap_extended_mobile":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_wide":{"unit":"em","top":"5","right":"2.5","bottom":"5","left":"2.5","isLinked":false},"ang_column_gap_wide_tablet":{"unit":"em","top":"2.5","right":"2.5","bottom":"2.5","left":"2.5","isLinked":true},"ang_column_gap_wide_mobile":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_wider":{"unit":"em","top":"7.5","right":"2.5","bottom":"7.5","left":"2.5","isLinked":false},"ang_column_gap_wider_tablet":{"unit":"em","top":"5","right":"2.5","bottom":"5","left":"2.5","isLinked":false},"ang_column_gap_wider_mobile":{"unit":"em","top":"2.5","right":"1.25","bottom":"2.5","left":"1.25","isLinked":false},"ang_text_size_small":{"unit":"em","size":0.8,"sizes":[]},"ang_text_size_medium":{"unit":"em","size":0.9,"sizes":[]},"ang_text_size_large":{"unit":"em","size":1,"sizes":[]},"ang_text_size_large_tablet":{"unit":"em","size":"","sizes":[]},"ang_text_size_large_mobile":{"unit":"em","size":0.9,"sizes":[]},"ang_text_size_xl":{"unit":"em","size":1.2,"sizes":[]},"ang_text_size_xl_tablet":{"unit":"em","size":1.2,"sizes":[]},"ang_text_size_xl_mobile":{"unit":"em","size":1,"sizes":[]},"ang_text_size_xxl":{"unit":"em","size":1.6,"sizes":[]},"ang_text_size_xxl_tablet":{"unit":"em","size":1.2,"sizes":[]},"ang_text_size_xxl_mobile":{"unit":"em","size":1.2,"sizes":[]},"ang_paragraph_font_family":"Barlow Semi Condensed","ang_heading_size_lh_small":{"unit":"em","size":1,"sizes":[]},"ang_heading_size_lh_medium":{"unit":"em","size":1,"sizes":[]},"ang_heading_size_lh_xl":{"unit":"em","size":"","sizes":[]},"ang_heading_size_lh_xxl":{"unit":"em","size":1,"sizes":[]},"ang_heading_size_lh_xxl_mobile":{"unit":"em","size":1.1,"sizes":[]},"ang_text_size_lh_small":{"unit":"em","size":"","sizes":[]},"ang_text_size_lh_medium":{"unit":"em","size":1.4,"sizes":[]},"ang_text_size_lh_large":{"unit":"em","size":1.7,"sizes":[]},"ang_text_size_lh_xl":{"unit":"em","size":1.6,"sizes":[]},"ang_text_size_lh_xl_tablet":{"unit":"em","size":"","sizes":[]},"ang_text_size_lh_xl_mobile":{"unit":"em","size":1.6,"sizes":[]},"ang_text_size_lh_xxl":{"unit":"em","size":1.5,"sizes":[]},"ang_paragraph_font_weight":"","ang_paragraph_text_transform":"","ang_paragraph_font_style":"","ang_paragraph_text_decoration":"","ang_default_heading_typography":"","ang_default_heading_font_size":"","ang_default_heading_font_size_mobile":"","ang_default_heading_font_size_tablet":"","ang_default_heading_font_style":"","ang_default_heading_font_weight":"","ang_default_heading_line_height":"","ang_default_heading_line_height_mobile":"","ang_default_heading_line_height_tablet":"","ang_default_heading_letter_spacing":"","ang_default_heading_letter_spacing_mobile":"","ang_default_heading_letter_spacing_tablet":"","ang_default_heading_text_decoration":"","ang_default_heading_text_transform":"","ang_make_token_global":"yes","ang_default_heading_font_family":"Barlow Semi Condensed","ang_column_gap_default_tablet":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_narrow_tablet":{"unit":"em","top":"0.5","right":"0.5","bottom":"0.5","left":"0.5","isLinked":true},"ang_column_gap_extended_tablet":{"unit":"em","top":"1.25","right":"2.5","bottom":"1.25","left":"2.5","isLinked":false},"ang_heading_1_text_transform":"uppercase","ang_heading_2_text_transform":"uppercase","ang_heading_3_text_transform":"uppercase","ang_heading_4_text_transform":"uppercase","ang_heading_5_text_transform":"uppercase","ang_heading_5_letter_spacing":{"unit":"px","size":1,"sizes":[]},"ang_body_font_size_tablet":{"unit":"px","size":"","sizes":[]},"ang_body_font_size_mobile":{"unit":"px","size":"","sizes":[]},"ang_body_text_transform":"","ang_body_font_style":"","ang_body_text_decoration":"","ang_body_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_body_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_body_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_body_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_body_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_1_font_family":"","ang_heading_1_font_style":"","ang_heading_1_text_decoration":"","ang_heading_1_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_1_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_1_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_1_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_1_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_2_font_family":"","ang_heading_2_font_style":"","ang_heading_2_text_decoration":"","ang_heading_2_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_2_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_2_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_2_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_2_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_3_font_family":"","ang_heading_3_font_style":"","ang_heading_3_text_decoration":"","ang_heading_3_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_3_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_3_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_3_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_3_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_4_font_family":"","ang_heading_4_font_style":"","ang_heading_4_text_decoration":"","ang_heading_4_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_4_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_4_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_4_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_4_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_5_font_family":"","ang_heading_5_font_style":"","ang_heading_5_text_decoration":"","ang_heading_5_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_5_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_5_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_5_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_6_font_family":"","ang_heading_6_font_style":"","ang_heading_6_text_decoration":"","ang_heading_6_line_height":{"unit":"em","size":"","sizes":[]},"ang_heading_6_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_6_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_6_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_6_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_small_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_small_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_medium_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_medium_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_large":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_large_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_large_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_xl_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_xl_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_xxl_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_small_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_small_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_small_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_small_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_medium_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_medium_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_medium_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_medium_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_large_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_large_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_xxl_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_xxl_mobile":{"unit":"px","size":"","sizes":[]}}',
			],
			[
				'slug'  => 'ang-dash',
				'title' => 'Dash',
				'meta'  => '{"ang_body_font_size":{"unit":"px","size":16,"sizes":[]},"ang_body_font_size_tablet":{"unit":"px","size":"","sizes":[]},"ang_body_font_size_mobile":{"unit":"px","size":15,"sizes":[]},"ang_body_line_height":{"unit":"em","size":1.7,"sizes":[]},"ang_body_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_body_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_body_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_body_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_body_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_default_heading_font_family":"Playfair Display","ang_heading_1_font_size":{"unit":"em","size":3.2,"sizes":[]},"ang_heading_1_font_size_tablet":{"unit":"em","size":2.5,"sizes":[]},"ang_heading_1_font_size_mobile":{"unit":"em","size":2,"sizes":[]},"ang_heading_1_line_height":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_1_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_1_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_1_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_1_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_1_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_2_font_size":{"unit":"em","size":2.5,"sizes":[]},"ang_heading_2_font_size_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_2_font_size_mobile":{"unit":"em","size":1.6,"sizes":[]},"ang_heading_2_font_weight":"900","ang_heading_2_line_height":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_2_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_2_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_2_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_2_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_2_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_3_font_size":{"unit":"em","size":2,"sizes":[]},"ang_heading_3_font_size_tablet":{"unit":"em","size":1.6,"sizes":[]},"ang_heading_3_font_size_mobile":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_3_font_weight":"900","ang_heading_3_line_height":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_3_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_3_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_3_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_3_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_3_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_4_font_size":{"unit":"em","size":1.6,"sizes":[]},"ang_heading_4_font_size_tablet":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_4_font_size_mobile":{"unit":"em","size":1,"sizes":[]},"ang_heading_4_font_weight":"bold","ang_heading_4_line_height":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_4_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_4_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_4_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_4_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_4_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_5_font_size":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_5_font_size_tablet":{"unit":"em","size":1,"sizes":[]},"ang_heading_5_font_size_mobile":{"unit":"em","size":0.9,"sizes":[]},"ang_heading_5_font_weight":"900","ang_heading_5_line_height":{"unit":"em","size":1,"sizes":[]},"ang_heading_5_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_5_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_5_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_heading_5_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_5_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_heading_6_font_size":{"unit":"em","size":0.9,"sizes":[]},"ang_heading_6_font_size_tablet":{"unit":"em","size":0.9,"sizes":[]},"ang_heading_6_font_size_mobile":{"unit":"em","size":0.8,"sizes":[]},"ang_heading_6_font_weight":"900","ang_heading_6_text_transform":"uppercase","ang_heading_6_line_height":{"unit":"em","size":"","sizes":[]},"ang_heading_6_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_heading_6_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_heading_6_letter_spacing":{"unit":"px","size":1,"sizes":[]},"ang_heading_6_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_6_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_size_small":{"unit":"em","size":1.2,"sizes":[]},"ang_size_small_tablet":{"unit":"em","size":"","sizes":[]},"ang_size_small_mobile":{"unit":"em","size":0.9,"sizes":[]},"ang_heading_size_lh_small":{"unit":"em","size":1,"sizes":[]},"ang_heading_size_lh_small_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_small_mobile":{"unit":"px","size":"","sizes":[]},"ang_size_medium":{"unit":"em","size":1.6,"sizes":[]},"ang_size_medium_tablet":{"unit":"em","size":"","sizes":[]},"ang_size_medium_mobile":{"unit":"em","size":1,"sizes":[]},"ang_heading_size_lh_medium":{"unit":"em","size":1,"sizes":[]},"ang_heading_size_lh_medium_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_medium_mobile":{"unit":"px","size":"","sizes":[]},"ang_size_large":{"unit":"em","size":2,"sizes":[]},"ang_size_large_tablet":{"unit":"em","size":"","sizes":[]},"ang_size_large_mobile":{"unit":"em","size":1.2,"sizes":[]},"ang_heading_size_lh_large":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_large_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_large_mobile":{"unit":"px","size":"","sizes":[]},"ang_size_xl":{"unit":"em","size":2.5,"sizes":[]},"ang_size_xl_tablet":{"unit":"em","size":2,"sizes":[]},"ang_size_xl_mobile":{"unit":"em","size":1.6,"sizes":[]},"ang_heading_size_lh_xl":{"unit":"em","size":"","sizes":[]},"ang_heading_size_lh_xl_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_xl_mobile":{"unit":"px","size":"","sizes":[]},"ang_size_xxl":{"unit":"em","size":4.2,"sizes":[]},"ang_size_xxl_tablet":{"unit":"em","size":3.6,"sizes":[]},"ang_size_xxl_mobile":{"unit":"em","size":2.5,"sizes":[]},"ang_heading_size_lh_xxl":{"unit":"em","size":1,"sizes":[]},"ang_heading_size_lh_xxl_tablet":{"unit":"px","size":"","sizes":[]},"ang_heading_size_lh_xxl_mobile":{"unit":"em","size":1.1,"sizes":[]},"ang_text_size_small":{"unit":"em","size":0.8,"sizes":[]},"ang_text_size_small_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_small_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_small":{"unit":"em","size":"","sizes":[]},"ang_text_size_lh_small_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_small_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_medium":{"unit":"em","size":0.9,"sizes":[]},"ang_text_size_medium_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_medium_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_medium":{"unit":"em","size":1.7,"sizes":[]},"ang_text_size_lh_medium_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_medium_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_large":{"unit":"em","size":1,"sizes":[]},"ang_text_size_large_tablet":{"unit":"em","size":"","sizes":[]},"ang_text_size_large_mobile":{"unit":"em","size":0.9,"sizes":[]},"ang_text_size_lh_large":{"unit":"em","size":1.7,"sizes":[]},"ang_text_size_lh_large_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_large_mobile":{"unit":"px","size":"","sizes":[]},"ang_text_size_xl":{"unit":"em","size":1.2,"sizes":[]},"ang_text_size_xl_tablet":{"unit":"em","size":1.2,"sizes":[]},"ang_text_size_xl_mobile":{"unit":"em","size":1,"sizes":[]},"ang_text_size_lh_xl":{"unit":"em","size":1.6,"sizes":[]},"ang_text_size_lh_xl_tablet":{"unit":"em","size":"","sizes":[]},"ang_text_size_lh_xl_mobile":{"unit":"em","size":1.6,"sizes":[]},"ang_text_size_xxl":{"unit":"em","size":1.6,"sizes":[]},"ang_text_size_xxl_tablet":{"unit":"em","size":1.2,"sizes":[]},"ang_text_size_xxl_mobile":{"unit":"em","size":1.2,"sizes":[]},"ang_text_size_lh_xxl":{"unit":"em","size":1.6,"sizes":[]},"ang_text_size_lh_xxl_tablet":{"unit":"px","size":"","sizes":[]},"ang_text_size_lh_xxl_mobile":{"unit":"px","size":"","sizes":[]},"ang_column_gap_default":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_narrow":{"unit":"em","top":"0.625","right":"0.625","bottom":"0.625","left":"0.625","isLinked":true},"ang_column_gap_extended":{"unit":"em","top":"2.5","right":"2.5","bottom":"2.5","left":"2.5","isLinked":true},"ang_column_gap_extended_mobile":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_wide_tablet":{"unit":"em","top":"2.5","right":"2.5","bottom":"2.5","left":"2.5","isLinked":true},"ang_column_gap_wide_mobile":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_wider":{"unit":"em","top":"7.5","right":"2.5","bottom":"7.5","left":"2.5","isLinked":false},"ang_column_gap_wider_tablet":{"unit":"em","top":"5","right":"2.5","bottom":"5","left":"2.5","isLinked":false},"ang_column_gap_wider_mobile":{"unit":"em","top":"2.5","right":"1.25","bottom":"2.5","left":"1.25","isLinked":false},"ang_paragraph_font_size":{"unit":"em","size":1.2,"sizes":[]},"ang_paragraph_font_size_tablet":{"unit":"em","size":1.2,"sizes":[]},"ang_paragraph_font_size_mobile":{"unit":"em","size":1,"sizes":[]},"ang_paragraph_line_height":{"unit":"em","size":1.6,"sizes":[]},"ang_paragraph_line_height_tablet":{"unit":"em","size":"","sizes":[]},"ang_paragraph_line_height_mobile":{"unit":"em","size":"","sizes":[]},"ang_paragraph_letter_spacing":{"unit":"px","size":"","sizes":[]},"ang_paragraph_letter_spacing_tablet":{"unit":"px","size":"","sizes":[]},"ang_paragraph_letter_spacing_mobile":{"unit":"px","size":"","sizes":[]},"ang_paragraph_typography":"custom","ang_paragraph_font_family":"Barlow Semi Condensed","ang_paragraph_font_weight":"","ang_paragraph_text_transform":"","ang_paragraph_font_style":"","ang_paragraph_text_decoration":"","ang_default_heading_typography":"","ang_default_heading_font_size":"","ang_default_heading_font_size_mobile":"","ang_default_heading_font_size_tablet":"","ang_default_heading_font_style":"","ang_default_heading_font_weight":"","ang_default_heading_line_height":"","ang_default_heading_line_height_mobile":"","ang_default_heading_line_height_tablet":"","ang_default_heading_letter_spacing":"","ang_default_heading_letter_spacing_mobile":"","ang_default_heading_letter_spacing_tablet":"","ang_default_heading_text_decoration":"","ang_default_heading_text_transform":"","ang_make_token_global":"yes","ang_column_gap_default_tablet":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_default_mobile":{"unit":"em","top":"1.25","right":"1.25","bottom":"1.25","left":"1.25","isLinked":true},"ang_column_gap_narrow_tablet":{"unit":"em","top":"0.5","right":"0.5","bottom":"0.5","left":"0.5","isLinked":true},"ang_column_gap_narrow_mobile":{"unit":"em","top":"0.625","right":"0.625","bottom":"0.625","left":"0.625","isLinked":true},"ang_column_gap_extended_tablet":{"unit":"em","top":"1.25","right":"2.5","bottom":"1.25","left":"2.5","isLinked":false},"ang_body_typography":"custom","ang_body_font_family":"Poppins","ang_body_font_weight":"normal","ang_heading_1_typography":"custom","ang_heading_1_font_weight":"900","ang_heading_2_typography":"custom","ang_heading_3_typography":"custom","ang_heading_4_typography":"custom","ang_heading_5_typography":"custom","ang_heading_6_typography":"custom","ang_column_gap_wide":{"unit":"em","top":"5","right":"2.5","bottom":"5","left":"2.5","isLinked":false},"ang_body_text_transform":"","ang_body_font_style":"","ang_body_text_decoration":"","ang_heading_1_font_family":"","ang_heading_1_text_transform":"","ang_heading_1_font_style":"","ang_heading_1_text_decoration":"","ang_heading_2_font_family":"","ang_heading_2_text_transform":"","ang_heading_2_font_style":"","ang_heading_2_text_decoration":"","ang_heading_3_font_family":"","ang_heading_3_text_transform":"","ang_heading_3_font_style":"","ang_heading_3_text_decoration":"","ang_heading_4_font_family":"","ang_heading_4_text_transform":"","ang_heading_4_font_style":"","ang_heading_4_text_decoration":"","ang_heading_5_font_family":"","ang_heading_5_text_transform":"","ang_heading_5_font_style":"","ang_heading_5_text_decoration":"","ang_heading_6_font_family":"","ang_heading_6_font_style":"","ang_heading_6_text_decoration":""}',
			],
		];

		return $posts;
	}
}
